// file:CCallerSample.cxx
/** @file
 * @brief サンプルプログラムcxxファイル
 * 
 * サンプルプログラムクラスの実装
 * @author yanch
 * @date 2006-10-21 作成
 * @date 2006-11-19 propファイルのパラメタ区切りにスペースが無い場合に対応
 * @date 2006-11-19 propファイルのパラメタ区切り文字にタブを使える様に対応
 * @date 2007-11-16 namespace に対応
 * @date 2007-11-16 unicode に対応
 * @date 2007-11-16 ソースファイルの拡張子をgccにならい、「.cxx」とした。
 * @date 2007-11-16 ヘッダファイルの拡張子を「.hxx」とした。
 * $Revision: 1.004$
 */
#define STRICT
#include <cfp/logger/CLogger.hxx>
#include "CCallerSample.hxx"

/**
 * ロッガーのインスタンスを取得。
 */
cfp::logger::CLogger CCallerSample::logger = 
		cfp::logger::CLogger::getLogger(L"default");

/**
 * コンストラクタ。
 */
CCallerSample::CCallerSample()
{
	logger.trace(L"CCallerSample::CCallerSample() -- START\n");
	logger.trace(L"CCallerSample::CCallerSample() -- END\n");
}

/**
 * デストラクタ。
 */
CCallerSample::~CCallerSample()
{
	logger.trace(L"CCallerSample::~CCallerSample() -- START\n");
	logger.trace(L"CCallerSample::~CCallerSample() -- END\n");
}

/**
 * ゲットインスタンス。
 * 
 * サンプルプログラムCCallerSampleの実体を得る。
 * 
 * @return 実体
 */
CCallerSample CCallerSample::getInstance()
{
	logger.trace(L"CCallerSample::getInstance() -- START\n");
	
	CCallerSample caller = CCallerSample::CCallerSample();
	
	logger.trace(L"CCallerSample::getInstance() -- END\n");
	return caller;
}

/**
 * CCallerSampleのメイン。
 * 
 * @param[in] argc main関数のパラメタ
 * @param[in] *argv[] main関数のパラメタ
 * @return 戻り値
 */
int CCallerSample::main(int argc, char *argv[])
{
	logger.trace(L"CCallerSample::main() -- START\n");
	
	logger.trace(L"トレース用ログですよ。\n");
	logger.debug(L"デバッグ用ログですよ。\n");
	logger.warn(L"ワーニング用ログですよ。\n");
	logger.error(L"エラー用ログですよ。\n");
	wprintf(L"isTrace() : [%d]\n", logger.isTrace());
	wprintf(L"isDebug() : [%d]\n", logger.isDebug());
	wprintf(L"isWarn()  : [%d]\n", logger.isWarn());
	wprintf(L"isError() : [%d]\n", logger.isError());
	
	logger.trace(L"CCallerSample::main() -- END\n");
	return 0;
}
