// file:CLoggerProfile.hxx
/** @file
 * @brief cfpロッガー・プロファイル・クラス・ヘッダファイル
 * 
 * ロッガー・プロファイル・クラスの宣言を記述。
 * @author yanch
 * @date 2006-10-21 作成
 * @date 2006-11-19 propファイルのパラメタ区切りにスペースが無い場合に対応
 * @date 2006-11-19 propファイルのパラメタ区切り文字にタブを使える様に対応
 * @date 2007-11-16 namespace に対応
 * @date 2007-11-16 unicode に対応
 * @date 2007-11-16 ソースファイルの拡張子をgccにならい、「.cxx」とした。
 * @date 2007-11-16 ヘッダファイルの拡張子を「.hxx」とした。
 * $Revision: 1.004$
 */
#ifndef CLOGGERPROFILE_HXX_
#define CLOGGERPROFILE_HXX_
#include <string>

namespace cfp
{
namespace logger
{
namespace sub
{
	class CLoggerProfile;
	
	/**
	 * @brief ロッガー・プラス・プロファイル・クラス。
	 * 
	 * CLoggerクラス内部より使用される。
	 * cfp_logger.propファイルの情報を扱う。
	 */
	class CLoggerProfile
	{
	private:
		/** ファイル用ログ出力フラグ */
		bool m_boAppenderFile;
		/** 標準出力用ログ出力フラグ */
		bool m_boAppenderStdout;
		/** デバッグログ用ログ出力フラグ */
		bool m_boDebug;
		/** エラーログ用ログ出力フラグ */
		bool m_boError;
		/** トレースログ用ログ出力フラグ */
		bool m_boTrace;
		/** ワーニングログ用ログ出力フラグ */
		bool m_boWarn;
		/** ファイルログ出力用ファイル名 */
		std::wstring m_strAppenderFileName;
		/** プロパティファイル名 */
		std::wstring m_strPropertyFileName;
		/** プロパティファイルの更新日時を保持 */
		time_t m_timeMTime;
		bool isUpdateProfile();
		void loadProfile();
		
	protected:
		
	public:
		CLoggerProfile();
		virtual ~CLoggerProfile();
		std::wstring getAppenderFileName();
		bool isAppenderFile();
		bool isAppenderStdout();
		bool isDebug();
		bool isError();
		bool isTrace();
		bool isWarn();
		
	};
}
}
}

#endif /*CLOGGERPROFILE_HXX_*/
