// file:CLoggerPropertyUtils.hxx
/** @file
 * @brief プロパティ・ユーティル・クラス・ヘッダファイル
 * 
 * プロパティ・ユーティル・クラスの宣言を記述。
 * @author yanch
 * @date 2006-10-21 作成
 * @date 2006-11-19 propファイルのパラメタ区切りにスペースが無い場合に対応
 * @date 2006-11-19 propファイルのパラメタ区切り文字にタブを使える様に対応
 * @date 2007-11-16 namespace に対応
 * @date 2007-11-16 unicode に対応
 * @date 2007-11-16 ソースファイルの拡張子をgccにならい、「.cxx」とした。
 * @date 2007-11-16 ヘッダファイルの拡張子を「.hxx」とした。
 * $Revision: 1.004$
 */
#ifndef CLOGGERPROPERTYUTILS_HXX_
#define CLOGGERPROPERTYUTILS_HXX_
#include <map>
#include <string>

namespace cfp
{
namespace logger
{
namespace sub
{
	class CLoggerPropertyUtils;
	
	/**
	 * @brief プロパティ・ユーティル・クラス。
	 * 
	 * .propファイルより値を取得するクラス。
	 */
	class CLoggerPropertyUtils
	{
	private:
		/** プロパティマップ */
		std::map<std::wstring, std::wstring> m_mapProperties;
		/** ファイル名 */
		std::wstring m_strFileName;
		void loadProperties();
		
	protected:
		CLoggerPropertyUtils();
		
	public:
		virtual ~CLoggerPropertyUtils();
		std::wstring getFileName();
		static CLoggerPropertyUtils getLoggerPropertyUtils(
				std::wstring strFileName);
		std::wstring getPropertyValue(std::wstring strKey);
		void setFileName(std::wstring strFileName);
	};
}
}
}

#endif /*CLOGGERPROPERTYUTILS_HXX_*/
